Offer
=====

.. autoclass:: moco_wrapper.models.Offer
    :members:

.. autoclass:: moco_wrapper.models.offer.OfferStatus
   :members:
   :undoc-members:

.. autoclass:: moco_wrapper.models.offer.OfferChangeAddress
   :members:
   :undoc-members: